@@ -2,20 +2,9 @@ import click
 
 from globus_cli.login_manager import LoginManager
 from globus_cli.parsing import command, endpoint_id_arg
-from globus_cli.services.auth import lookup_identity_name
-from globus_cli.services.transfer import get_client
 from globus_cli.termio import FORMAT_TEXT_RECORD, formatted_print
 
 
-def _shared_with_keyfunc(rule):
-    if rule["principal_type"] == "identity":
-        return lookup_identity_name(rule["principal"])
-    elif rule["principal_type"] == "group":
-        return "https://app.globus.org/groups/{}".format(rule["principal"])
-    else:
-        return rule["principal_type"]
-
-
 @command(
     "show",
     short_help="Display an access control rule",
@@ -30,13 +19,22 @@ $ globus endpoint permission show $ep_id $rule_id
 @endpoint_id_arg
 @click.argument("rule_id")
 @LoginManager.requires_login(LoginManager.AUTH_RS, LoginManager.TRANSFER_RS)
-def show_command(endpoint_id, rule_id):
+def show_command(*, login_manager: LoginManager, endpoint_id, rule_id):
     """
     Show detailed information about a single access control rule on an endpoint.
     """
-    client = get_client()
+    transfer_client = login_manager.get_transfer_client()
+    auth_client = login_manager.get_auth_client()
 
-    rule = client.get_endpoint_acl_rule(endpoint_id, rule_id)
+    def _shared_with_keyfunc(rule):
+        if rule["principal_type"] == "identity":
+            return auth_client.lookup_identity_name(rule["principal"])
+        elif rule["principal_type"] == "group":
+            return "https://app.globus.org/groups/{}".format(rule["principal"])
+        else:
+            return rule["principal_type"]
+
+    rule = transfer_client.get_endpoint_acl_rule(endpoint_id, rule_id)
     formatted_print(
         rule,
         text_format=FORMAT_TEXT_RECORD,
