@@ -1,5 +1,6 @@
 from globus_cli.parsing import group
 
+from .index import index_command
 from .ingest import ingest_command
 from .query import query_command
 from .task import task_command
@@ -11,5 +12,6 @@ def search_command():
 
 
 search_command.add_command(ingest_command)
+search_command.add_command(index_command)
 search_command.add_command(query_command)
 search_command.add_command(task_command)
