@@ -1,7 +1,7 @@
 import uuid
 
+from globus_cli.login_manager import LoginManager
 from globus_cli.parsing import command
-from globus_cli.services.search import get_search_client
 from globus_cli.termio import FORMAT_TEXT_TABLE, formatted_print
 
 from .._common import index_id_arg
@@ -16,9 +16,10 @@ TASK_FIELDS = [
 
 @command("list", short_help="List recent Tasks for an index")
 @index_id_arg
-def list_command(index_id: uuid.UUID):
+@LoginManager.requires_login(LoginManager.SEARCH_RS)
+def list_command(*, login_manager: LoginManager, index_id: uuid.UUID):
     """List the 1000 most recent Tasks for an index"""
-    search_client = get_search_client()
+    search_client = login_manager.get_search_client()
     formatted_print(
         search_client.get_task_list(index_id),
         fields=TASK_FIELDS,
